## Beschreibung
<!-- Was wurde geaendert und warum? -->

## Typ der Aenderung
- [ ] Bug Fix
- [ ] Feature
- [ ] Breaking Change
- [ ] Refactoring / Chore
- [ ] Dokumentation

## Verknuepfte Issues
<!-- Closes #XX -->

## Testabdeckung
- [ ] Tests hinzugefuegt / aktualisiert
- [ ] Alle Tests gruen (`pytest`)

## Checkliste
- [ ] Keine hard-codierten Secrets
- [ ] Ready for Review
